==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libconnection/072mark_text_q.cc <==
// Mark a text.
//
// $Id: 072mark_text_q.cc,v 1.6 1994/07/16 17:34:50 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include <stdlib.h>
#include <iostream.h>
#include <assert.h>
#include "prot-a-LyStr.h"
#include "question.h"
#include "connection.h"
#include "mark_text_q.h"
#include "obsolete.h"		// for mark_text_old_question

    
mark_text_question::mark_text_question(Connection *conn,
				       Text_no text,
				       unsigned char mark_type)
    : question(conn), mark_text_old(NULL)
{
    prot_a_LyStr   s;

    if (conn->get_server_info()->get_version() >= 10400) {
	s << ref_no() << " 72 " << text << ' ' << int(mark_type) << '\n';
	port->send_question(s);
    } else {
	if (mark_type == 0) {
	    cerr << "Cannot mark with 0 on this server!\n";
            mark_type  = 1;	// +++Error handling
	}

	mark_text_old = new mark_text_old_question(conn, text, mark_type);
    }
}


mark_text_question::~mark_text_question()
{
    if (mark_text_old != NULL)
	delete mark_text_old;
}


Status 
mark_text_question::status()
{
    if (mark_text_old == NULL)
	return question::status();
    else
	return mark_text_old->status();
}


Status 
mark_text_question::receive()
{
    if (mark_text_old == NULL)
	return question::receive();
    else {
	deallocate_refno();
	return mark_text_old->receive();
    }
}


Kom_err
mark_text_question::error()
{
    if (mark_text_old == NULL)
	return question::error();
    else
	return mark_text_old->error();
}


void
mark_text_question::parser(prot_a_LyStr& str)
{
    state = st_ok;
    deallocate_refno();
}


void
mark_text_question::result()
{
    return;
}

==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libconnection/072mark_text_q.cc <==
// Mark a text.
//
// $Id: 072mark_text_q.cc,v 1.8 1995/11/14 06:06:30 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <stdlib.h>
#include <iostream.h>
#include <assert.h>
#include "prot-a-LyStr.h"
#include "question.h"
#include "connection.h"
#include "mark_text_q.h"
#include "obsolete.h"		// for mark_text_old_question

    
mark_text_question::mark_text_question(Connection *conn,
				       Text_no text,
				       unsigned char mark_type)
    : question(conn), mark_text_old(NULL)
{
    prot_a_LyStr   s;

    if (conn->get_server_info()->get_version() >= 10400) {
	s << ref_no() << " 72 " << text << ' ' << int(mark_type) << '\n';
	port->send_question(s);
    } else {
	if (mark_type == 0) {
	    cerr << "Cannot mark with 0 on this server!\n";
            mark_type  = 1;	// +++Error handling
	}

	mark_text_old = new mark_text_old_question(conn, text, mark_type);
    }
}


mark_text_question::~mark_text_question()
{
    if (mark_text_old != NULL)
	delete mark_text_old;
}


Status 
mark_text_question::status()
{
    if (mark_text_old == NULL)
	return question::status();
    else
	return mark_text_old->status();
}


Status 
mark_text_question::receive()
{
    if (mark_text_old == NULL)
	return question::receive();
    else {
	deallocate_refno();
	return mark_text_old->receive();
    }
}


Kom_err
mark_text_question::error()
{
    if (mark_text_old == NULL)
	return question::error();
    else
	return mark_text_old->error();
}


void
mark_text_question::parser(prot_a_LyStr &)
{
    state = st_ok;
    deallocate_refno();
}


void
mark_text_question::result()
{
    return;
}
